@@ -45,6 +45,7 @@ class QLDemo:
             huffman.fill(length)
             ack = huffman.readlong()
             cmd = huffman.readbyte()
+            r = None
             if cmd == SVC_GAMESTATE: 
                 r = self.parse_gamestate()
             elif cmd == SVC_SERVERCOMMAND: 
@@ -53,7 +54,7 @@ class QLDemo:
                 r = self.parse_snapshot()
                 self.snapshots.append(r)
             self.packets.append(r)
-            yield r
+            if r: yield r
 
     def parse_gamestate(self):
         ack=huffman.readlong()
@@ -249,7 +250,7 @@ class QLDemo:
         command.scores['TEAM_BLUE']['invisibility_time']  = ls[32]
         command.scores['TEAM_BLUE']['flag_time']  = ls[33]
 
-        num_scores = ls[34]
+        num_scores = int(ls[34])
         command.scores['TEAM_RED']['score'] = ls[35]
         command.scores['TEAM_BLUE']['score'] = ls[36]
         offset = 0
