@@ -57,11 +57,13 @@ def main():
         if i.__class__ is Snapshot:
             first_snap=i
             break
-    for i in range(-1,-5,-1):
-        if d.packets[i].__class__ is Snapshot:
-            last_snap=d.packets[i]
+    rev = d.packets
+    rev.reverse()
+    for i in rev:
+        if i.__class__ is Snapshot:
+            last_snap=i
             break
-    duration = (last_snap.serverTime - first_snap.serverTime) / 1000
+    duration = (last_snap.serverTime - first_snap.serverTime) / 1000 if first_snap and last_snap else None
     
     output = {'filename': args.file.split(os.sep)[-1],
               'gametype': gametype_to_string(
